@@ -22,9 +22,7 @@ THE SOFTWARE.
 package cmd
 
 import (
-	"encoding/gob"
 	"fmt"
-	"os"
 	"path/filepath"
 
 	"github.com/MakeNowJust/heredoc/v2"
@@ -36,7 +34,7 @@ import (
 
 func init() {
 	rootCmd.AddCommand(diffCmd)
-	diffCmd.Flags().StringP("in", "i", "", "Path to IPSW .idiff file")
+	// diffCmd.Flags().StringP("in", "i", "", "Path to IPSW .idiff file")
 	diffCmd.Flags().StringP("title", "t", "", "Title of the diff")
 	diffCmd.Flags().BoolP("markdown", "m", false, "Save diff as Markdown file")
 	diffCmd.Flags().Bool("json", false, "Save diff as JSON file")
@@ -56,7 +54,7 @@ func init() {
 	diffCmd.Flags().StringP("output", "o", "", "Folder to save diff output")
 	diffCmd.MarkFlagDirname("output")
 	diffCmd.MarkFlagsMutuallyExclusive("markdown", "json", "html")
-	viper.BindPFlag("diff.in", diffCmd.Flags().Lookup("in"))
+	// viper.BindPFlag("diff.in", diffCmd.Flags().Lookup("in"))
 	viper.BindPFlag("diff.title", diffCmd.Flags().Lookup("title"))
 	viper.BindPFlag("diff.markdown", diffCmd.Flags().Lookup("markdown"))
 	viper.BindPFlag("diff.json", diffCmd.Flags().Lookup("json"))
@@ -85,11 +83,8 @@ var diffCmd = &cobra.Command{
 		# Diff two IPSWs with KDKs
 		❯ ipsw diff <old.ipsw> <new.ipsw> --output <output/folder> --markdown 
 			--kdk /Library/Developer/KDKs/KDK_15.0_24A5264n.kdk/System/Library/Kernels/kernel.release.t6031 
-			--kdk /Library/Developer/KDKs/KDK_15.0_24A5279h.kdk/System/Library/Kernels/kernel.release.t6031
-		# Use a previously saved .idiff file
-		❯ ipsw diff --in <path/to/.idiff> --output <output/folder> --markdown`),
-	Args:          cobra.MaximumNArgs(2),
-	SilenceUsage:  true,
+			--kdk /Library/Developer/KDKs/KDK_15.0_24A5279h.kdk/System/Library/Kernels/kernel.release.t6031`),
+	Args:          cobra.ExactArgs(2),
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) (err error) {
 
@@ -98,52 +93,30 @@ var diffCmd = &cobra.Command{
 		}
 
 		// verify flags
-		if !viper.IsSet("diff.in") && len(args) != 2 {
-			return fmt.Errorf("you must specify two IPSWs to diff OR a .idiff file via the --in flag")
-		} else if viper.IsSet("diff.in") && len(args) != 0 {
-			return fmt.Errorf("you cannot specify both an --in .idiff file AND IPSWs to diff")
-		} else if viper.IsSet("diff.kdk") && len(viper.GetStringSlice("diff.kdk")) != 2 {
+		if len(viper.GetStringSlice("diff.kdk")) > 0 && len(viper.GetStringSlice("diff.kdk")) != 2 {
 			return fmt.Errorf("you must specify two KDKs to diff; example: --kdk <KDK1> --kdk <KDK2>")
 		}
 
-		var d *diff.Diff
-
-		if viper.IsSet("diff.in") {
-			idiff, err := os.Open(viper.GetString("diff.in"))
-			if err != nil {
-				return fmt.Errorf("failed to open .idiff file: %w", err)
-			}
-			defer idiff.Close()
-			if err := gob.NewDecoder(idiff).Decode(&d); err != nil {
-				return fmt.Errorf("failed to decode .idiff file '%s': %w", idiff.Name(), err)
-			}
-			// override output folder
-			d.SetOutput(viper.GetString("diff.output"))
-		} else {
-			if len(args) != 2 {
-				return fmt.Errorf("you must specify two IPSWs to diff")
-			}
-			d = diff.New(&diff.Config{
-				Title:        viper.GetString("diff.title"),
-				IpswOld:      filepath.Clean(args[0]),
-				IpswNew:      filepath.Clean(args[1]),
-				KDKs:         viper.GetStringSlice("diff.kdk"),
-				LaunchD:      viper.GetBool("diff.launchd"),
-				Firmware:     viper.GetBool("diff.fw"),
-				Features:     viper.GetBool("diff.feat"),
-				Files:        viper.GetBool("diff.files"),
-				CStrings:     viper.GetBool("diff.strs"),
-				FuncStarts:   viper.GetBool("diff.starts"),
-				Entitlements: viper.GetBool("diff.ent"),
-				AllowList:    viper.GetStringSlice("diff.allow-list"),
-				BlockList:    viper.GetStringSlice("diff.block-list"),
-				Signatures:   viper.GetString("diff.signatures"),
-				Output:       viper.GetString("diff.output"),
-				Verbose:      Verbose,
-			})
-			if err := d.Diff(); err != nil {
-				return err
-			}
+		d := diff.New(&diff.Config{
+			Title:        viper.GetString("diff.title"),
+			IpswOld:      filepath.Clean(args[0]),
+			IpswNew:      filepath.Clean(args[1]),
+			KDKs:         viper.GetStringSlice("diff.kdk"),
+			LaunchD:      viper.GetBool("diff.launchd"),
+			Firmware:     viper.GetBool("diff.fw"),
+			Features:     viper.GetBool("diff.feat"),
+			Files:        viper.GetBool("diff.files"),
+			CStrings:     viper.GetBool("diff.strs"),
+			FuncStarts:   viper.GetBool("diff.starts"),
+			Entitlements: viper.GetBool("diff.ent"),
+			AllowList:    viper.GetStringSlice("diff.allow-list"),
+			BlockList:    viper.GetStringSlice("diff.block-list"),
+			Signatures:   viper.GetString("diff.signatures"),
+			Output:       viper.GetString("diff.output"),
+			Verbose:      Verbose,
+		})
+		if err := d.Diff(); err != nil {
+			return err
 		}
 
 		if viper.IsSet("diff.output") {
