@@ -26,7 +26,6 @@ import (
 	"os"
 	"path/filepath"
 
-	"github.com/apex/log"
 	"github.com/blacktop/go-apfs"
 	"github.com/blacktop/ipsw/internal/magic"
 	"github.com/spf13/cobra"
@@ -52,15 +51,10 @@ var apfsCmd = &cobra.Command{
 	Use:           "apfs",
 	Short:         "🚧 List/Extract APFS files",
 	Args:          cobra.MinimumNArgs(1),
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	Hidden:        true,
 	RunE: func(cmd *cobra.Command, args []string) (err error) {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-
 		// flags
 		// pattern := viper.GetString("disk.hfs.search")
 		// flat := viper.GetBool("disk.hfs.flat")
