@@ -93,7 +93,7 @@ func init() {
 	})
 	downloadOtaCmd.Flags().Bool("driver-kit", false, "Extract DriverKit dyld_shared_cache(s) from remote OTA zip")
 	downloadOtaCmd.Flags().String("pattern", "", "Download remote files that match regex")
-	downloadOtaCmd.Flags().BoolP("flat", "f", false, "Do NOT perserve directory structure when downloading with --pattern")
+	downloadOtaCmd.Flags().BoolP("flat", "f", false, "Do NOT preserve directory structure when downloading with --pattern")
 	downloadOtaCmd.Flags().Bool("info", false, "Show all the latest OTAs available")
 	downloadOtaCmd.Flags().StringP("output", "o", "", "Folder to download files to")
 	downloadOtaCmd.MarkFlagDirname("output")
@@ -160,11 +160,6 @@ var downloadOtaCmd = &cobra.Command{
 		var err error
 		var ver *semver.Version
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		// settings
 		proxy := viper.GetString("download.ota.proxy")
 		insecure := viper.GetBool("download.ota.insecure")
@@ -225,7 +220,7 @@ var downloadOtaCmd = &cobra.Command{
 		if getRSR && len(build) == 0 {
 			return fmt.Errorf("for now you will need to supply a --build number when using --rsr")
 		}
-		if viper.GetBool("download.ota.delta") && len(build) == 0 || len(version) == 0 {
+		if viper.GetBool("download.ota.delta") && (len(build) == 0 || len(version) == 0) {
 			return fmt.Errorf("for now you will need to supply a --version AND --build number when using --delta")
 		}
 		if len(build) == 0 {
