@@ -26,9 +26,7 @@ import (
 	"os"
 	"path/filepath"
 
-	"github.com/apex/log"
 	"github.com/blacktop/ipsw/pkg/dyld"
-	"github.com/fatih/color"
 	"github.com/pkg/errors"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
@@ -37,6 +35,7 @@ import (
 func init() {
 	ObjcCmd.AddCommand(objcClassCmd)
 	objcClassCmd.Flags().StringP("image", "i", "", "dylib image to search")
+	viper.BindPFlag("dyld.objc.class.image", objcClassCmd.Flags().Lookup("image"))
 }
 
 // objcClassCmd represents the class command
@@ -51,12 +50,7 @@ var objcClassCmd = &cobra.Command{
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
-		imageName, _ := cmd.Flags().GetString("image")
+		imageName := viper.GetString("dyld.objc.class.image")
 
 		dscPath := filepath.Clean(args[0])
 
