@@ -25,7 +25,6 @@ package frida
 
 import (
 	"github.com/spf13/cobra"
-	"github.com/spf13/viper"
 )
 
 const fridaVersion = "17.2.0"
@@ -40,13 +39,6 @@ var FridaCmd = &cobra.Command{
 	Aliases: []string{"f"},
 	Short:   "Run Frida commands",
 	Args:    cobra.NoArgs,
-	PersistentPreRun: func(cmd *cobra.Command, args []string) {
-		viper.BindPFlag("color", cmd.Flags().Lookup("color"))
-		viper.BindPFlag("no-color", cmd.Flags().Lookup("no-color"))
-		viper.BindPFlag("verbose", cmd.Flags().Lookup("verbose"))
-		viper.BindPFlag("frida.udid", cmd.Flags().Lookup("udid"))
-		viper.BindPFlag("diff-tool", cmd.Flags().Lookup("diff-tool"))
-	},
 	Run: func(cmd *cobra.Command, args []string) {
 		cmd.Help()
 	},
