@@ -64,13 +64,8 @@ var ibootCmd = &cobra.Command{
 	Short:         "Dump iBoot files",
 	Args:          cobra.ExactArgs(1),
 	SilenceErrors: true,
-	SilenceUsage:  true,
 	RunE: func(cmd *cobra.Command, args []string) (err error) {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-
 		// flags
 		showVersion := viper.GetBool("fw.iboot.version")
 		showStrings := viper.GetBool("fw.iboot.strings")
