@@ -28,7 +28,6 @@ import (
 	"github.com/apex/log"
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/blacktop/ipsw/pkg/usb/companion"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -36,23 +35,18 @@ import (
 func init() {
 	IDevCmd.AddCommand(compCmd)
 	compCmd.Flags().BoolP("json", "j", false, "Display companions as JSON")
+	viper.BindPFlag("idev.comp.json", compCmd.Flags().Lookup("json"))
 }
 
 // compCmd represents the comp command
 var compCmd = &cobra.Command{
 	Use:           "comp",
 	Short:         "List all paired companion devices",
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
-		udid, _ := cmd.Flags().GetString("udid")
-		asJSON, _ := cmd.Flags().GetBool("json")
+		udid := viper.GetString("idev.udid")
+		asJSON := viper.GetBool("idev.comp.json")
 
 		if len(udid) == 0 {
 			dev, err := utils.PickDevice()
