@@ -30,7 +30,7 @@ import (
 // dvtMonCmd represents the mon command
 var dvtMonCmd = &cobra.Command{
 	Use:   "mon",
-	Short: "A brief description of your command",
+	Short: "Monitor DVT services",
 	Long: `A longer description that spans multiple lines and likely contains examples
 and usage of using your command. For example:
 
