@@ -33,7 +33,6 @@ import (
 	"github.com/apex/log"
 	"github.com/blacktop/ipsw/internal/magic"
 	"github.com/blacktop/ipsw/internal/utils"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -58,17 +57,11 @@ func init() {
 
 // ddiCmd represents the ddi command
 var ddiCmd = &cobra.Command{
-	Use:   "ddi",
-	Short: "DDI commands",
-	// SilenceUsage:  true,
+	Use:           "ddi",
+	Short:         "DDI commands",
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		if !viper.IsSet("idev.img.ddi.info") &&
 			!viper.IsSet("idev.img.ddi.xcode") &&
 			!viper.IsSet("idev.img.ddi.source") &&
