@@ -30,11 +30,13 @@ import (
 	"strings"
 	"syscall"
 
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/apex/log"
 	"github.com/blacktop/ipsw/internal/commands/mount"
 	"github.com/blacktop/ipsw/internal/download"
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/spf13/cobra"
+	"github.com/spf13/viper"
 )
 
 func init() {
@@ -43,6 +45,11 @@ func init() {
 	mountCmd.Flags().StringP("key", "k", "", "DMG key")
 	mountCmd.Flags().Bool("lookup", false, "Lookup DMG keys on theapplewiki.com")
 	mountCmd.Flags().String("pem-db", "", "AEA pem DB JSON file")
+	mountCmd.Flags().StringP("mount-point", "m", "", "Custom mount point (default: /tmp/<dmg>.mount)")
+	viper.BindPFlag("mount.key", mountCmd.Flags().Lookup("key"))
+	viper.BindPFlag("mount.lookup", mountCmd.Flags().Lookup("lookup"))
+	viper.BindPFlag("mount.pem-db", mountCmd.Flags().Lookup("pem-db"))
+	viper.BindPFlag("mount.mount-point", mountCmd.Flags().Lookup("mount-point"))
 }
 
 // mountCmd represents the mount command
@@ -50,9 +57,24 @@ var mountCmd = &cobra.Command{
 	Use:           "mount [fs|sys|app|exc] IPSW",
 	Aliases:       []string{"mo", "mnt"},
 	Short:         "Mount DMG from IPSW",
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	Args:          cobra.ExactArgs(2),
+	Example: heredoc.Doc(`
+		# Mount the filesystem DMG from an IPSW
+		$ ipsw mount fs iPhone15,2_16.5_20F66_Restore.ipsw
+
+		# Mount the system DMG with a specific decryption key
+		$ ipsw mount sys iPhone.ipsw --key "a1b2c3d4e5f6..."
+
+		# Mount fs DMG and lookup keys from theapplewiki.com
+		$ ipsw mount fs iPod5,1_7.1.2_11D257_Restore.ipsw --lookup
+
+		# Mount dyld shared cache (exc) DMG with AEA pem DB
+		$ ipsw mount exc iPhone.ipsw --pem-db /path/to/pem.json
+
+		# Mount to a custom mount point
+		$ ipsw mount fs iPhone.ipsw --mount-point /mnt/ios-filesystem
+	`),
 	ValidArgsFunction: func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		if len(args) == 0 {
 			return mount.DmgTypes, cobra.ShellCompDirectiveNoFileComp
@@ -66,9 +88,10 @@ var mountCmd = &cobra.Command{
 		}
 
 		// flags
-		key, _ := cmd.Flags().GetString("key")
-		lookupKeys, _ := cmd.Flags().GetBool("lookup")
-		pemDB, _ := cmd.Flags().GetString("pem-db")
+		key := viper.GetString("mount.key")
+		lookupKeys := viper.GetBool("mount.lookup")
+		pemDB := viper.GetString("mount.pem-db")
+		mountPoint := viper.GetString("mount.mount-point")
 		// validate flags
 		if len(key) > 0 && lookupKeys {
 			return fmt.Errorf("cannot use --key AND --lookup flags together")
@@ -112,7 +135,7 @@ var mountCmd = &cobra.Command{
 			keys = key
 		}
 
-		mctx, err := mount.DmgInIPSW(args[1], args[0], pemDB, keys)
+		mctx, err := mount.DmgInIPSW(args[1], args[0], pemDB, keys, mountPoint)
 		if err != nil {
 			return fmt.Errorf("failed to mount %s DMG: %v", args[0], err)
 		}
