@@ -43,12 +43,6 @@ var OtaCmd = &cobra.Command{
 	Use:   "ota",
 	Short: "Parse OTAs",
 	Args:  cobra.NoArgs,
-	PersistentPreRun: func(cmd *cobra.Command, args []string) {
-		viper.BindPFlag("color", cmd.Flags().Lookup("color"))
-		viper.BindPFlag("no-color", cmd.Flags().Lookup("no-color"))
-		viper.BindPFlag("verbose", cmd.Flags().Lookup("verbose"))
-		viper.BindPFlag("diff-tool", cmd.Flags().Lookup("diff-tool"))
-	},
 	Run: func(cmd *cobra.Command, args []string) {
 		cmd.Help()
 	},
