@@ -36,7 +36,6 @@ import (
 	"github.com/blacktop/ipsw/pkg/dyld"
 	"github.com/blacktop/ipsw/pkg/kernelcache"
 	"github.com/blacktop/ipsw/pkg/ota"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -74,23 +73,17 @@ var otaExtractCmd = &cobra.Command{
 	Aliases:       []string{"e"},
 	Short:         "Extract OTA payload files",
 	Args:          cobra.MinimumNArgs(1),
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		// flags
 		decomp := viper.GetBool("ota.extract.decomp")
 		cryptex := viper.GetString("ota.extract.cryptex")
 		// validate flags
-		if len(args) > 1 && viper.IsSet("ota.extract.pattern") {
+		if len(args) > 1 && viper.GetString("ota.extract.pattern") != "" {
 			return fmt.Errorf("cannot use both FILENAME and flag for --pattern")
 		}
-		if viper.IsSet("ota.extract.cryptex") && !slices.Contains(validCryptexes, cryptex) {
+		if viper.GetString("ota.extract.cryptex") != "" && !slices.Contains(validCryptexes, cryptex) {
 			return fmt.Errorf("invalid --cryptex: '%s' (must be one of: %s)", cryptex, strings.Join(validCryptexes, ", "))
 		}
 
@@ -108,17 +101,17 @@ var otaExtractCmd = &cobra.Command{
 			return fmt.Errorf("failed to get OTA folder: %v", err)
 		}
 
-		if viper.IsSet("ota.extract.output") {
+		if viper.GetString("ota.extract.output") != "" {
 			output = filepath.Join(viper.GetString("ota.extract.output"), output)
 			if err := os.MkdirAll(output, 0o755); err != nil {
 				return fmt.Errorf("failed to create output directory: %v", err)
 			}
 		}
 
-		if viper.IsSet("ota.extract.cryptex") || viper.GetBool("ota.extract.dyld") || viper.GetBool("ota.extract.kernel") || viper.IsSet("ota.extract.pattern") {
+		if viper.GetString("ota.extract.cryptex") != "" || viper.GetBool("ota.extract.dyld") || viper.GetBool("ota.extract.kernel") || viper.GetString("ota.extract.pattern") != "" {
 			cwd, _ := os.Getwd()
 			/* CRYPTEX */
-			if viper.IsSet("ota.extract.cryptex") {
+			if viper.GetString("ota.extract.cryptex") != "" {
 				log.Infof("Extracting %s Cryptex", cryptex)
 				out, err := o.ExtractCryptex(cryptex, output)
 				if err != nil {
@@ -187,7 +180,7 @@ var otaExtractCmd = &cobra.Command{
 				}
 			}
 			/* PATTERN */
-			if viper.IsSet("ota.extract.pattern") {
+			if viper.GetString("ota.extract.pattern") != "" {
 				re, err := regexp.Compile(viper.GetString("ota.extract.pattern"))
 				if err != nil {
 					return fmt.Errorf("failed to compile regex pattern '%s': %v", viper.GetString("ota.extract.pattern"), err)
@@ -249,7 +242,7 @@ var otaExtractCmd = &cobra.Command{
 		}
 
 		/* ALL FILES */
-		if len(args) == 1 && !viper.IsSet("ota.extract.pattern") {
+		if len(args) == 1 && viper.GetString("ota.extract.pattern") == "" {
 			log.Info("Extracting All Files From OTA")
 			for _, f := range o.Files() {
 				if f.IsDir() {
