@@ -25,9 +25,7 @@ import (
 	"encoding/json"
 	"fmt"
 
-	"github.com/apex/log"
 	"github.com/blacktop/ipsw/pkg/ota"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -44,15 +42,9 @@ var otaInfoCmd = &cobra.Command{
 	Aliases:       []string{"i"},
 	Short:         "Display OTA metadata",
 	Args:          cobra.MinimumNArgs(1),
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		o, err := ota.Open(args[0], viper.GetString("ota.key-val"))
 		if err != nil {
 			return fmt.Errorf("failed to open OTA: %v", err)
