@@ -28,7 +28,6 @@ import (
 	"github.com/apex/log"
 	"github.com/blacktop/ipsw/internal/ssh"
 	"github.com/blacktop/ipsw/pkg/shsh"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -43,15 +42,9 @@ var sshShshBlobCmd = &cobra.Command{
 	Aliases:       []string{"sh"},
 	Short:         "Get SHSH blobs from device",
 	Args:          cobra.NoArgs,
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		// parent flags
 		viper.BindPFlag("ssh.host", cmd.Flags().Lookup("host"))
 		viper.BindPFlag("ssh.port", cmd.Flags().Lookup("port"))
