@@ -36,7 +36,6 @@ import (
 	"github.com/blacktop/ipsw/pkg/crashlog"
 	"github.com/blacktop/ipsw/pkg/dyld"
 	"github.com/blacktop/ipsw/pkg/info"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -84,15 +83,8 @@ var symbolicateCmd = &cobra.Command{
 		  ❯ ipsw symbolicate Delta-2024-04-20-135807.ips
 		  ⨯ please supply a dyld_shared_cache for iPhone13,3 running 14.5 (18E5154f)`),
 	Args:          cobra.MinimumNArgs(1),
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
-
-		if Verbose {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		/* flags */
 		all := viper.GetBool("symbolicate.all")
 		running := viper.GetBool("symbolicate.running")
