@@ -272,9 +272,10 @@ func scanEnts(ipswPath, dmgPath, dmgType, pemDbPath string) (map[string]string,
 	if filepath.Ext(dmgPath) == ".aea" {
 		var err error
 		dmgPath, err = aea.Decrypt(&aea.DecryptConfig{
-			Input:  dmgPath,
-			Output: filepath.Dir(dmgPath),
-			PemDB:  pemDbPath,
+			Input:    dmgPath,
+			Output:   filepath.Dir(dmgPath),
+			PemDB:    pemDbPath,
+			Insecure: false, // TODO: make insecure configurable
 		})
 		if err != nil {
 			return nil, fmt.Errorf("failed to parse AEA encrypted DMG: %v", err)
@@ -283,7 +284,7 @@ func scanEnts(ipswPath, dmgPath, dmgType, pemDbPath string) (map[string]string,
 	}
 
 	utils.Indent(log.Debug, 2)(fmt.Sprintf("Mounting %s %s", dmgType, dmgPath))
-	mountPoint, alreadyMounted, err := utils.MountDMG(dmgPath)
+	mountPoint, alreadyMounted, err := utils.MountDMG(dmgPath, "")
 	if err != nil {
 		return nil, fmt.Errorf("failed to mount DMG: %v", err)
 	}
