@@ -45,7 +45,7 @@ func (c Context) Unmount() error {
 }
 
 // DmgInIPSW will mount a DMG from an IPSW
-func DmgInIPSW(path, typ, pemDbPath string, keys any) (*Context, error) {
+func DmgInIPSW(path, typ, pemDbPath string, keys any, customMountPoint string) (*Context, error) {
 	var err error
 
 	ipswPath := filepath.Clean(path)
@@ -119,9 +119,10 @@ func DmgInIPSW(path, typ, pemDbPath string, keys any) (*Context, error) {
 	if filepath.Ext(extractedDMG) == ".aea" {
 		defer os.Remove(extractedDMG) // remove the encrypted AEA DMG decrypting and mounting
 		extractedDMG, err = aea.Decrypt(&aea.DecryptConfig{
-			Input:  extractedDMG,
-			Output: filepath.Dir(extractedDMG),
-			PemDB:  pemDbPath,
+			Input:    extractedDMG,
+			Output:   filepath.Dir(extractedDMG),
+			PemDB:    pemDbPath,
+			Insecure: false, // TODO: make insecure configurable
 		})
 		if err != nil {
 			return nil, fmt.Errorf("failed to parse AEA encrypted DMG: %v", err)
@@ -153,7 +154,7 @@ func DmgInIPSW(path, typ, pemDbPath string, keys any) (*Context, error) {
 		}
 	}
 
-	mp, am, err := utils.MountDMG(extractedDMG)
+	mp, am, err := utils.MountDMG(extractedDMG, customMountPoint)
 	if err != nil {
 		return nil, fmt.Errorf("failed to mount %s: %v", extractedDMG, err)
 	}
