@@ -355,16 +355,17 @@ func mountDMG(ctx *Context) (err error) {
 	}
 	if filepath.Ext(ctx.SystemOsDmgPath) == ".aea" {
 		ctx.SystemOsDmgPath, err = aea.Decrypt(&aea.DecryptConfig{
-			Input:  ctx.SystemOsDmgPath,
-			Output: filepath.Dir(ctx.SystemOsDmgPath),
-			PemDB:  ctx.PemDB,
+			Input:    ctx.SystemOsDmgPath,
+			Output:   filepath.Dir(ctx.SystemOsDmgPath),
+			PemDB:    ctx.PemDB,
+			Insecure: false, // TODO: make insecure configurable
 		})
 		if err != nil {
 			return fmt.Errorf("failed to parse AEA encrypted DMG: %v", err)
 		}
 	}
 	utils.Indent(log.Info, 2)(fmt.Sprintf("Mounting %s", ctx.SystemOsDmgPath))
-	ctx.MountPath, ctx.IsMounted, err = utils.MountDMG(ctx.SystemOsDmgPath)
+	ctx.MountPath, ctx.IsMounted, err = utils.MountDMG(ctx.SystemOsDmgPath, "")
 	if err != nil {
 		if !errors.Is(err, utils.ErrMountResourceBusy) {
 			return fmt.Errorf("failed to mount DMG: %v", err)
