@@ -2,12 +2,14 @@ package download
 
 import (
 	"crypto/tls"
+	"crypto/x509"
 	"encoding/json"
 	"fmt"
 	"io"
 	"net/http"
 	"sort"
 
+	"github.com/blacktop/ipsw/internal/download/rootcert"
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/hashicorp/go-version"
 )
@@ -38,10 +40,15 @@ func GetAssetSets(proxy string, insecure bool) (*AssetSets, error) {
 	req.Header.Set("Content-Type", "application/json")
 	req.Header.Add("User-Agent", utils.RandomAgent())
 
+	certpool := x509.NewCertPool()
+	certpool.AddCert(rootcert.AppleRootCA)
 	client := &http.Client{
 		Transport: &http.Transport{
-			Proxy:           GetProxy(proxy),
-			TLSClientConfig: &tls.Config{InsecureSkipVerify: insecure},
+			Proxy: GetProxy(proxy),
+			TLSClientConfig: &tls.Config{
+				RootCAs:    certpool,
+				MinVersion: tls.VersionTLS12,
+			},
 		},
 	}
 
@@ -180,6 +187,12 @@ func (a *AssetSets) latest(platform string) (string, string) {
 	}
 
 	sort.Sort(version.Collection(versions))
+
+	// Check if we have any versions
+	if len(versions) == 0 {
+		return "failed to get latest", "failed to get latest"
+	}
+
 	if len(v2b[versions[len(versions)-1].Original()]) == 0 {
 		return "failed to get latest", "failed to get latest"
 	}
