@@ -43,9 +43,10 @@ func scanDmg(ipswPath, dmgPath, dmgType, pemDB string, handler func(string, stri
 	if filepath.Ext(dmgPath) == ".aea" {
 		var err error
 		dmgPath, err = aea.Decrypt(&aea.DecryptConfig{
-			Input:  dmgPath,
-			Output: filepath.Dir(dmgPath),
-			PemDB:  pemDB,
+			Input:    dmgPath,
+			Output:   filepath.Dir(dmgPath),
+			PemDB:    pemDB,
+			Insecure: false, // TODO: make insecure configurable
 		})
 		if err != nil {
 			return fmt.Errorf("failed to parse AEA encrypted DMG: %v", err)
@@ -53,7 +54,7 @@ func scanDmg(ipswPath, dmgPath, dmgType, pemDB string, handler func(string, stri
 		defer os.Remove(dmgPath)
 	}
 	utils.Indent(log.Debug, 2)(fmt.Sprintf("Mounting %s %s", dmgType, dmgPath))
-	mountPoint, alreadyMounted, err := utils.MountDMG(dmgPath)
+	mountPoint, alreadyMounted, err := utils.MountDMG(dmgPath, "")
 	if err != nil {
 		return fmt.Errorf("failed to mount DMG: %v", err)
 	}
