@@ -276,7 +276,9 @@ func (i *Info) String() string {
 			}
 			iStr += fmt.Sprintf("\n%s\n", prodName)
 			iStr += fmt.Sprintf(" > %s_%s_%s\n", dt.ProductType, strings.ToUpper(dt.BoardConfig), i.Plists.BuildManifest.ProductBuildVersion)
-			iStr += fmt.Sprintf("   - TimeStamp: %s\n", dt.Timestamp.Format("02 Jan 2006 15:04:05 MST"))
+			if !dt.Timestamp.IsZero() {
+				iStr += fmt.Sprintf("   - TimeStamp: %s\n", dt.Timestamp.Format("02 Jan 2006 15:04:05 MST"))
+			}
 			if len(kcs[strings.ToLower(dt.BoardConfig)]) > 0 {
 				iStr += fmt.Sprintf("   - KernelCache: %s\n", strings.Join(kcs[strings.ToLower(dt.BoardConfig)], ", "))
 			}
@@ -741,7 +743,7 @@ func Parse(ipswPath string, keys ...string) (*Info, error) {
 }
 
 // ParseZipFiles parses plist files and devicetree in a remote zip file
-func ParseZipFiles(files []*zip.File) (*Info, error) {
+func ParseZipFiles(files []*zip.File, keys ...string) (*Info, error) {
 	var err error
 
 	i := &Info{}
@@ -750,7 +752,7 @@ func ParseZipFiles(files []*zip.File) (*Info, error) {
 	if err != nil {
 		return nil, fmt.Errorf("failed to parse plists: %v", err)
 	}
-	i.DeviceTrees, err = devicetree.ParseZipFiles(files)
+	i.DeviceTrees, err = devicetree.ParseZipFiles(files, keys...)
 	if err != nil {
 		if errors.Is(err, devicetree.ErrEncryptedDeviceTree) { // FIXME: this is a hack to avoid stopping the parsing of the metadata info
 			log.Error(err.Error())
